@@ -4,10 +4,12 @@ import numpy as np
 import datetime
 from contextlib import contextmanager
 
-from xbbg import const, pipeline
+from xbbg import __version__, const, pipeline
 from xbbg.io import logs, files, storage
 from xbbg.core import utils, conn, process
 
+__all__ = ['__version__']
+
 
 def bdp(tickers, flds, **kwargs) -> pd.DataFrame:
     """
@@ -33,7 +35,7 @@ def bdp(tickers, flds, **kwargs) -> pd.DataFrame:
     logger.debug(f'Sending request to Bloomberg ...\n{request}')
     conn.send_request(request=request, **kwargs)
 
-    res = pd.DataFrame(process.rec_events(func=process.process_ref))
+    res = pd.DataFrame(process.rec_events(func=process.process_ref, **kwargs))
     if kwargs.get('raw', False): return res
     if res.empty or any(fld not in res for fld in ['ticker', 'field']):
         return pd.DataFrame()
@@ -80,7 +82,7 @@ def bds(tickers, flds, **kwargs) -> pd.DataFrame:
         logger.debug(f'Sending request to Bloomberg ...\n{request}')
         conn.send_request(request=request, **kwargs)
 
-        res = pd.DataFrame(process.rec_events(func=process.process_ref))
+        res = pd.DataFrame(process.rec_events(func=process.process_ref, **kwargs))
         if kwargs.get('raw', False): return res
         if res.empty or any(fld not in res for fld in ['ticker', 'field']):
             return pd.DataFrame()
@@ -144,7 +146,7 @@ def bdh(
     logger.debug(f'Sending request to Bloomberg ...\n{request}')
     conn.send_request(request=request, **kwargs)
 
-    res = pd.DataFrame(process.rec_events(process.process_hist))
+    res = pd.DataFrame(process.rec_events(process.process_hist, **kwargs))
     if kwargs.get('raw', False): return res
     if res.empty or any(fld not in res for fld in ['ticker', 'date']):
         return pd.DataFrame()
@@ -155,6 +157,8 @@ def bdh(
         .unstack(level=0)
         .rename_axis(index=None, columns=[None, None])
         .swaplevel(0, 1, axis=1)
+        .reindex(columns=utils.flatten(tickers), level=0)
+        .reindex(columns=utils.flatten(flds), level=1)
     )
 
 
@@ -245,7 +249,7 @@ def bdib(
     logger.debug(f'Sending request to Bloomberg ...\n{request}')
     conn.send_request(request=request, **kwargs)
 
-    res = pd.DataFrame(process.rec_events(func=process.process_bar))
+    res = pd.DataFrame(process.rec_events(func=process.process_bar, **kwargs))
     if res.empty or ('time' not in res):
         logger.warning(f'No data for {info_log} ...')
         missing.update_missing(**miss_kw)
@@ -309,7 +313,7 @@ def bdtick(ticker, dt, session='allday', types=None, **kwargs) -> pd.DataFrame:
     logger.debug(f'Sending request to Bloomberg ...\n{request}')
     conn.send_request(request=request)
 
-    res = pd.DataFrame(process.rec_events(func=process.process_bar, typ='t'))
+    res = pd.DataFrame(process.rec_events(func=process.process_bar, typ='t', **kwargs))
     if kwargs.get('raw', False): return res
     if res.empty or ('time' not in res): return pd.DataFrame()
 
@@ -354,6 +358,12 @@ def earning(
     kwargs.pop('raw', None)
     ovrd = 'G' if by[0].upper() == 'G' else 'P'
     new_kw = dict(Product_Geo_Override=ovrd)
+
+    year = kwargs.pop('year', None)
+    periods = kwargs.pop('periods', None)
+    if year: kwargs['Eqy_Fund_Year'] = year
+    if periods: kwargs['Number_Of_Periods'] = periods
+
     header = bds(tickers=ticker, flds='PG_Bulk_Header', **new_kw, **kwargs)
     if ccy: kwargs['Eqy_Fund_Crncy'] = ccy
     if level: kwargs['PG_Hierarchy_Level'] = level
@@ -498,7 +508,7 @@ def beqs(
 
     logger.debug(f'Sending request to Bloomberg ...\n{request}')
     conn.send_request(request=request, **kwargs)
-    res = pd.DataFrame(process.rec_events(func=process.process_ref))
+    res = pd.DataFrame(process.rec_events(func=process.process_ref, **kwargs))
     if res.empty:
         if kwargs.get('trial', 0): return pd.DataFrame()
         else: return beqs(
@@ -602,8 +612,9 @@ def live(
                         }}
                         yield {
                             key: value for key, value in values.items()
-                            if value not in [np.nan, pd.NaT, None]
-                            or (isinstance(value, str) and value.strip())
+                            if value not in [np.nan, pd.NaT, None] or (
+                                isinstance(value, str) and value.strip()
+                            )
                         }
                         cnt += 1
             except ValueError as e: logger.debug(e)
